# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.list_operations_response import ListOperationsResponse

class TestListOperationsResponse(unittest.TestCase):
    """ListOperationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListOperationsResponse:
        """Test ListOperationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListOperationsResponse`
        """
        model = ListOperationsResponse()
        if include_optional:
            return ListOperationsResponse(
                next_page_token = '',
                operations = [
                    google_drive_ti.models.operation.Operation(
                        done = True, 
                        error = google_drive_ti.models.status.Status(
                            code = 56, 
                            details = [
                                None
                                ], 
                            message = '', ), 
                        metadata = google_drive_ti.models.metadata.metadata(), 
                        name = '', 
                        response = google_drive_ti.models.response.response(), )
                    ]
            )
        else:
            return ListOperationsResponse(
        )
        """

    def testListOperationsResponse(self):
        """Test ListOperationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
