# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_image_media_metadata import FileImageMediaMetadata

class TestFileImageMediaMetadata(unittest.TestCase):
    """FileImageMediaMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileImageMediaMetadata:
        """Test FileImageMediaMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileImageMediaMetadata`
        """
        model = FileImageMediaMetadata()
        if include_optional:
            return FileImageMediaMetadata(
                aperture = 1.337,
                camera_make = '',
                camera_model = '',
                color_space = '',
                exposure_bias = 1.337,
                exposure_mode = '',
                exposure_time = 1.337,
                flash_used = True,
                focal_length = 1.337,
                height = 56,
                iso_speed = 56,
                lens = '',
                location = google_drive_ti.models.file_image_media_metadata_location.File_imageMediaMetadata_location(
                    altitude = 1.337, 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                max_aperture_value = 1.337,
                metering_mode = '',
                rotation = 56,
                sensor = '',
                subject_distance = 56,
                time = '',
                white_balance = '',
                width = 56
            )
        else:
            return FileImageMediaMetadata(
        )
        """

    def testFileImageMediaMetadata(self):
        """Test FileImageMediaMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
