# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_video_media_metadata import FileVideoMediaMetadata

class TestFileVideoMediaMetadata(unittest.TestCase):
    """FileVideoMediaMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileVideoMediaMetadata:
        """Test FileVideoMediaMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileVideoMediaMetadata`
        """
        model = FileVideoMediaMetadata()
        if include_optional:
            return FileVideoMediaMetadata(
                duration_millis = '',
                height = 56,
                width = 56
            )
        else:
            return FileVideoMediaMetadata(
        )
        """

    def testFileVideoMediaMetadata(self):
        """Test FileVideoMediaMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
