# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.files_api import FilesApi


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesApi()

    def tearDown(self) -> None:
        pass

    def test_drive_files_copy(self) -> None:
        """Test case for drive_files_copy

        """
        pass

    def test_drive_files_create(self) -> None:
        """Test case for drive_files_create

        """
        pass

    def test_drive_files_delete(self) -> None:
        """Test case for drive_files_delete

        """
        pass

    def test_drive_files_download(self) -> None:
        """Test case for drive_files_download

        """
        pass

    def test_drive_files_empty_trash(self) -> None:
        """Test case for drive_files_empty_trash

        """
        pass

    def test_drive_files_export(self) -> None:
        """Test case for drive_files_export

        """
        pass

    def test_drive_files_generate_ids(self) -> None:
        """Test case for drive_files_generate_ids

        """
        pass

    def test_drive_files_get(self) -> None:
        """Test case for drive_files_get

        """
        pass

    def test_drive_files_list(self) -> None:
        """Test case for drive_files_list

        """
        pass

    def test_drive_files_list_labels(self) -> None:
        """Test case for drive_files_list_labels

        """
        pass

    def test_drive_files_modify_labels(self) -> None:
        """Test case for drive_files_modify_labels

        """
        pass

    def test_drive_files_update(self) -> None:
        """Test case for drive_files_update

        """
        pass

    def test_drive_files_watch(self) -> None:
        """Test case for drive_files_watch

        """
        pass


if __name__ == '__main__':
    unittest.main()
