# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.app_list import AppList

class TestAppList(unittest.TestCase):
    """AppList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppList:
        """Test AppList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AppList`
        """
        model = AppList()
        if include_optional:
            return AppList(
                default_app_ids = [
                    ''
                    ],
                items = [
                    google_drive_ti.models.app.App(
                        authorized = True, 
                        create_in_folder_template = '', 
                        create_url = '', 
                        has_drive_wide_scope = True, 
                        icons = [
                            google_drive_ti.models.app_icons.AppIcons(
                                category = '', 
                                icon_url = '', 
                                size = 56, )
                            ], 
                        id = '', 
                        installed = True, 
                        kind = 'drive#app', 
                        long_description = '', 
                        name = '', 
                        object_type = '', 
                        open_url_template = '', 
                        primary_file_extensions = [
                            ''
                            ], 
                        primary_mime_types = [
                            ''
                            ], 
                        product_id = '', 
                        product_url = '', 
                        secondary_file_extensions = [
                            ''
                            ], 
                        secondary_mime_types = [
                            ''
                            ], 
                        short_description = '', 
                        supports_create = True, 
                        supports_import = True, 
                        supports_multi_open = True, 
                        supports_offline_create = True, 
                        use_by_default = True, )
                    ],
                kind = 'drive#appList',
                self_link = ''
            )
        else:
            return AppList(
        )
        """

    def testAppList(self):
        """Test AppList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
