# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.access_proposal_role_and_view import AccessProposalRoleAndView
from typing import Optional, Set
from typing_extensions import Self

class AccessProposal(BaseModel):
    """
    The Access Proposal resource for outstanding access proposals on a file
    """ # noqa: E501
    create_time: Optional[StrictStr] = Field(default=None, description="The creation time", alias="createTime")
    file_id: Optional[StrictStr] = Field(default=None, description="The file id that the proposal for access is on", alias="fileId")
    proposal_id: Optional[StrictStr] = Field(default=None, description="The id of the access proposal", alias="proposalId")
    recipient_email_address: Optional[StrictStr] = Field(default=None, description="The email address of the user that will receive permissions if accepted", alias="recipientEmailAddress")
    request_message: Optional[StrictStr] = Field(default=None, description="The message that the requester added to the proposal", alias="requestMessage")
    requester_email_address: Optional[StrictStr] = Field(default=None, description="The email address of the requesting user", alias="requesterEmailAddress")
    roles_and_views: Optional[List[AccessProposalRoleAndView]] = Field(default=None, description="A wrapper for the role and view of an access proposal.", alias="rolesAndViews")
    __properties: ClassVar[List[str]] = ["createTime", "fileId", "proposalId", "recipientEmailAddress", "requestMessage", "requesterEmailAddress", "rolesAndViews"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessProposal from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in roles_and_views (list)
        _items = []
        if self.roles_and_views:
            for _item_roles_and_views in self.roles_and_views:
                if _item_roles_and_views:
                    _items.append(_item_roles_and_views.to_dict())
            _dict['rolesAndViews'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessProposal from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createTime": obj.get("createTime"),
            "fileId": obj.get("fileId"),
            "proposalId": obj.get("proposalId"),
            "recipientEmailAddress": obj.get("recipientEmailAddress"),
            "requestMessage": obj.get("requestMessage"),
            "requesterEmailAddress": obj.get("requesterEmailAddress"),
            "rolesAndViews": [AccessProposalRoleAndView.from_dict(_item) for _item in obj["rolesAndViews"]] if obj.get("rolesAndViews") is not None else None
        })
        return _obj


