# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.revision_list import RevisionList

class TestRevisionList(unittest.TestCase):
    """RevisionList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RevisionList:
        """Test RevisionList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RevisionList`
        """
        model = RevisionList()
        if include_optional:
            return RevisionList(
                kind = 'drive#revisionList',
                next_page_token = '',
                revisions = [
                    google_drive_ti.models.revision.Revision(
                        export_links = google_drive_ti.models.export_links.exportLinks(), 
                        id = '', 
                        keep_forever = True, 
                        kind = 'drive#revision', 
                        last_modifying_user = google_drive_ti.models.user.User(
                            display_name = '', 
                            email_address = '', 
                            kind = 'drive#user', 
                            me = True, 
                            permission_id = '', 
                            photo_link = '', ), 
                        md5_checksum = '', 
                        mime_type = '', 
                        modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        original_filename = '', 
                        publish_auto = True, 
                        published = True, 
                        published_link = '', 
                        published_outside_domain = True, 
                        size = '', )
                    ]
            )
        else:
            return RevisionList(
        )
        """

    def testRevisionList(self):
        """Test RevisionList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
